import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

export const constantRoutes = [{
        path: '/login',
        // redirect: '/login',
        component: () =>
            import ('@/views/login/index'),
        hidden: true
    },

    {
        path: '/404',
        component: () =>
            import ('@/views/404'),
        hidden: true
    },

    {
        path: '/',
        component: Layout,
        redirect: '/main',
        children: [{
            path: 'main',
            name: 'Main',
            component: () =>
                import ('@/views/main/index'),
            meta: { title: '首页', icon: 'el-icon-s-home' }
        }]
    },

    {
        path: '/device',
        component: Layout,
        redirect: '/device/workbench',
        name: 'Device',
        meta: { title: '设备管理系统', icon: 'el-icon-mic' },
        children: [{
                path: 'workbench',
                name: 'Workbench',
                component: () =>
                    import ('@/views/device/workbench/index'),
                meta: { title: '工作台', icon: 'el-icon-postcard' }
            },
            {
                path: 'workbench/details',
                name: 'WorkbenchDetails',
                component: () =>
                    import ('@/views/device/workbench/details'),
                meta: { title: '设备详情', icon: '' },
                hidden: true
            },
            {
                path: 'info/add',
                name: 'Add',
                hidden: true,
                component: () =>
                    import ('@/views/car/carinfo/add'),
                meta: { title: '车辆添加' }
            },
            {
                path: 'info',
                name: 'Info',
                component: () =>
                    import ('@/views/device/info/index'),
                meta: { title: '设备信息', icon: 'el-icon-info' }
            },
            {
                path: 'info/details',
                name: 'InfoDetails',
                hidden: true,
                component: () =>
                    import ('@/views/device/info/details'),
                meta: { title: '批次电池详情', icon: 'el-icon-document' }
            },
            {
                path: 'storage',
                name: 'Storage',
                component: () =>
                    import ('@/views/device/storage/index'),
                meta: { title: '设备入库', icon: 'el-icon-sell' }
            },
            {
                path: 'storage/batchWarehousing',
                name: 'BatchWarehousing',
                component: () =>
                    import ('@/views/device/storage/batchWarehousing'),
                meta: { title: '批次入库', icon: 'el-icon-document' },
                hidden: true
            },
            {
                path: 'storage/warehousing',
                name: 'Warehousing',
                component: () =>
                    import ('@/views/device/storage/warehousing'),
                meta: { title: '入库', icon: 'el-icon-document' },
                hidden: true
            },
            {
                path: 'allocation',
                name: 'Allocation',
                component: () =>
                    import ('@/views/device/allocation/index'),
                meta: { title: '设备调拨', icon: 'el-icon-help' }
            },
            {
                path: 'allocation/allocationBack',
                name: 'AllocationBack',
                component: () =>
                    import ('@/views/device/allocation/allocationBack'),
                hidden: true,
                meta: { title: '调回平台', icon: 'el-icon-document' }
            },
            {
                path: 'allocation/allocationAdd',
                name: 'AllocationAdd',
                component: () =>
                    import ('@/views/device/allocation/allocationAdd'),
                hidden: true,
                meta: { title: '新增调拨', icon: 'el-icon-document' }
            },
            {
                path: 'allocation/details',
                name: 'AllocationDetails',
                component: () =>
                    import ('@/views/device/allocation/details'),
                hidden: true,
                meta: { title: '查看详情', icon: 'el-icon-document' }
            },
            {
                path: 'delivery',
                name: 'Delivery',
                component: () =>
                    import ('@/views/device/delivery/index'),
                meta: { title: '设备出库', icon: 'el-icon-picture-outline' }
            },
            {
                path: 'delivery/details',
                name: 'DeliveryDetail',
                hidden: true,
                component: () =>
                    import ('@/views/device/delivery/details'),
                meta: { title: '出库详情', icon: 'el-icon-picture-outline' }
            },
            {
                path: 'delivery/batchOut',
                name: 'BatchOut',
                hidden: true,
                component: () =>
                    import ('@/views/device/delivery/batchOut'),
                meta: { title: '批次出库', icon: 'el-icon-picture-outline' }
            },
            {
                path: 'delivery/batchOutDetail',
                name: 'BatchOutDetail',
                hidden: true,
                component: () =>
                    import ('@/views/device/delivery/batchOutDetail'),
                meta: { title: '批次出库-查看详情', icon: 'el-icon-picture-outline' }
            },
            {
                path: 'handle',
                name: 'Handle',
                component: () =>
                    import ('@/views/device/handle/index'),
                meta: { title: '设备处置', icon: 'el-icon-toilet-paper' }
            },
            {
                path: 'configure',
                name: 'Configure',
                component: () =>
                    import ('@/views/device/configure/index'),
                meta: { title: '设备基础配置', icon: 'el-icon-document' }
            },
            {
                path: 'configure/batteryCode',
                name: 'BatteryCode',
                hidden: true,
                component: () =>
                    import ('@/views/device/configure/batteryCode'),
                meta: { title: '电池编码管理', icon: 'el-icon-document' }
            },
            {
                path: 'configure/carCode',
                name: 'CarCode',
                hidden: true,
                component: () =>
                    import ('@/views/device/configure/carCode'),
                meta: { title: '电动车编码管理', icon: 'el-icon-document' }
            },
            {
                path: 'configure/partsCode',
                name: 'PartsCode',
                hidden: true,
                component: () =>
                    import ('@/views/device/configure/partsCode'),
                meta: { title: '配件编码管理', icon: 'el-icon-document' }
            },
            {
                path: 'configure/accessoriesType',
                name: 'AccessoriesType',
                hidden: true,
                component: () =>
                    import ('@/views/device/configure/accessoriesType'),
                meta: { title: '配件类型管理', icon: 'el-icon-document' }
            },
            {
                path: 'agreement',
                name: 'Agreement',
                component: () =>
                    import ('@/views/device/bms/index'),
                meta: { title: 'bms协议管理', icon: 'el-icon-document' }
            },
        ]
    },

    {
        path: '/assetsManager',
        component: Layout,
        redirect: '/assetsManager/profit',
        name: '资产收益分析',
        meta: { title: '资产管理系统', icon: 'el-icon-setting' },
        children: [{
                path: 'profit',
                name: 'Profit',
                component: () =>
                    import ('@/views/assetsManager/profit/index'),
                meta: { title: '资产收益分析', icon: 'el-icon-user-solid' }
            },
            {
                path: 'investment',
                name: 'Investment',
                component: () =>
                    import ('@/views/assetsManager/investment/index'),
                meta: { title: '资产投资分析', icon: 'el-icon-user-solid' }
            },
            {
                path: 'setUp',
                name: 'SetUp',
                component: () =>
                    import ('@/views/assetsManager/setUp/index'),
                meta: { title: '资产管理设置', icon: 'el-icon-user-solid' }
            }
        ]
    },

    {
        path: '/customer',
        component: Layout,
        redirect: '/customer',
        name: 'Customer',
        meta: { title: '客户管理系统', icon: 'el-icon-notebook-1' },
        children: [{
            path: 'customer',
            name: 'Customer',
            component: () =>
                import ('@/views/customer/index'),
            meta: { title: '客户管理系统', icon: 'el-icon-s-custom' }
        }]
    },

    {
        path: '/dataAnalysis',
        component: Layout,
        redirect: '/dataAnalysis',
        name: 'DataAnalysis',
        meta: { title: '数据分析系统', icon: 'el-icon-notebook-1' },
        children: [{
            path: 'dataAnalysis',
            name: 'DataAnalysis',
            component: () =>
                import ('@/views/dataAnalysis/index'),
            meta: { title: '数据分析系统', icon: 'dashboard' }
        }]
    },

    {
        path: '/sys',
        component: Layout,
        redirect: '/sys/user',
        name: '账号管理',
        meta: { title: '系统设置', icon: 'el-icon-setting' },
        children: [{
                path: 'user',
                name: 'User',
                component: () =>
                    import ('@/views/sys/user/index'),
                meta: { title: '账号管理', icon: 'el-icon-user-solid' }
            },
            {
                path: 'userAdd',
                name: 'UserAdd',
                component: () =>
                    import ('@/views/sys/user/add'),
                hidden: true,
                meta: { title: '新增用户', icon: 'el-icon-document' }
            },
            {
                path: 'role',
                name: 'Role',
                component: () =>
                    import ('@/views/sys/role/index'),
                meta: { title: '权限管理', icon: 'el-icon-document' }
            },
            {
                path: 'dict',
                name: 'Dict',
                component: () =>
                    import ('@/views/sys/sys_dict/index'),
                meta: { title: '字典表', icon: 'el-icon-document' }
            },
        ]
    },

    { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
    const newRouter = createRouter()
    router.matcher = newRouter.matcher // reset router
}

export default router